import Vue from 'vue'

import Cookies from 'js-cookie'

import Element from 'element-ui'
import './assets/styles/element-variables.scss'

import '@/assets/styles/index.scss' // global css
import '@/assets/styles/ruoyi.scss' // ruoyi css
import App from './App'
import store from './store'
import router from './router'
import directive from './directive' // directive
import plugins from './plugins' // plugins
import { download } from '@/utils/request'
import './assets/icons' // icon
import './permission' // permission control
import { getDicts } from "@/api/system/dict/data";
import { getConfigKey } from "@/api/system/config";
import { parseTime, resetForm, addDateRange, selectDictLabel, selectDictLabels, handleTree, inputMoney, uninputMoney } from "@/utils/ruoyi";
// 分页组件
import Pagination from "@/components/Pagination";
// 自定义表格工具组件
import RightToolbar from "@/components/RightToolbar"
// 富文本组件
import Editor from "@/components/Editor"
// 文件上传组件
import FileUpload from "@/components/FileUpload"
// 图片上传组件
import ImageUpload from "@/components/ImageUpload"
// 图片预览组件
import ImagePreview from "@/components/ImagePreview"
// 字典标签组件
import DictTag from '@/components/DictTag'
// 头部标签组件
import VueMeta from 'vue-meta'
// 字典数据组件
import DictData from '@/components/DictData'
// 投放时间段组件
import ScheduleTime from "@/components/ScheduleTime"
import qs from 'qs'

// 全局方法挂载
Vue.prototype.inputMoney = inputMoney
Vue.prototype.uninputMoney = uninputMoney

Vue.prototype.getDicts = getDicts
Vue.prototype.getConfigKey = getConfigKey
Vue.prototype.parseTime = parseTime
Vue.prototype.resetForm = resetForm
Vue.prototype.addDateRange = addDateRange
Vue.prototype.selectDictLabel = selectDictLabel
Vue.prototype.selectDictLabels = selectDictLabels
Vue.prototype.download = download
Vue.prototype.handleTree = handleTree
Vue.prototype.qs = qs

// 全局组件挂载
Vue.component('DictTag', DictTag)
Vue.component('Pagination', Pagination)
Vue.component('RightToolbar', RightToolbar)
Vue.component('Editor', Editor)
Vue.component('FileUpload', FileUpload)
Vue.component('ImageUpload', ImageUpload)
Vue.component('ImagePreview', ImagePreview)
Vue.component('ScheduleTime', ScheduleTime)

Vue.use(directive)
Vue.use(plugins)
Vue.use(VueMeta)
DictData.install()


Vue.prototype.allMoney = function (num, n) {
  n = n || 2;
  let symbol = ",";
  if (num === null) return num;
  if (typeof num !== "number")
    throw new TypeError("num参数应该是一个number类型");
  if (n < 0) throw new Error("参数n不应该小于0");
  let hasDot = parseInt(num) != num; //这里检测num是否为小数，true表示小数
  let m = n != undefined && n != null ? n : 1;
  num =
    m == 0
      ? num.toFixed(m) + "."
      : hasDot
        ? n
          ? num.toFixed(n)
          : num
        : num.toFixed(m);
  symbol = symbol || ",";
  num = num
    .toString()
    .replace(/(\d)(?=(\d{3})+\.)/g, function (match, p1, p2) {
      return p1 + symbol;
    });
  if (n == 0 || (!hasDot && !n)) {
    //如果n为0或者传入的num是整数并且没有指定整数的保留位数，则去掉前面操作中的小数位
    num = num.substring(0, num.indexOf("."));
  }
  return num;
}

/**
 * If you don't want to use mock-server
 * you want to use MockJs for mock api
 * you can execute: mockXHR()
 *
 * Currently MockJs will be used in the production environment,
 * please remove it before going online! ! !
 */

Vue.use(Element, {
  size: Cookies.get('size') || 'medium' // set element-ui default size
})

Vue.config.productionTip = false

new Vue({
  el: '#app',
  router,
  store,
  render: h => h(App)
})
